==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Stiki",
    "Address book name" : "Ime imenika",
    "Import" : "Uvozi",
    "No contacts in here" : "Ni dodanega nobenega stika!",
    "Name" : "Ime",
    "Organization" : "Ustanova",
    "Title" : "Naslov",
    "Add field ..." : "Dodaj polje ...",
    "Add contact" : "Dodaj stik",
    "No search result for {query}" : "Ni zadetkov iskanja za {query}",
    "All contacts" : "Vsi stiki",
    "Not grouped" : "Brez skupine",
    "Post Office Box" : "Poštni predal",
    "Postal Code" : "Poštna številka",
    "City" : "Mesto",
    "State or province" : "Zvezna država ali provinca",
    "Country" : "Država",
    "Address" : "Naslov",
    "(new group)" : "(nova skupina)",
    "New contact" : "Nov stik",
    "{addressbook} shared by {owner}" : "Souporabo imenika {addressbook} je omogočil uporabnik {owner}",
    "No contacts in file. Only VCard files are allowed." : "V datoteki ni vpisanih stikov. Dovoljeni so le vpisi datotek VCard.",
    "Nickname" : "Vzdevek",
    "Notes" : "Sporočilca",
    "Website" : "Spletna stran",
    "Federated Cloud ID" : "ID zveznega oblaka",
    "Home" : "Domači naslov",
    "Work" : "Službeni naslov",
    "Other" : "Drugo",
    "Groups" : "Skupine",
    "Birthday" : "Rojstni dan",
    "Email" : "Elektronski naslov",
    "Instant messaging" : "Hipno sporočanje",
    "Phone" : "Telefon",
    "Mobile" : "Mobilni telefon",
    "Fax" : "Faks",
    "Fax home" : "Domači faks",
    "Fax work" : "Službeni faks",
    "Pager" : "Pozivnik",
    "Voice" : "Glas",
    "Social Network" : "Socialno omrežje",
    "Settings" : "Nastavitve"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Stiki",
    "Address book name" : "Ime imenika",
    "Import" : "Uvozi",
    "The selected image is too big (max 1MB)" : "Izbrana slika je prevelika (omejitev je 1 MB).",
    "No contacts in here" : "Ni dodanega nobenega stika!",
    "Name" : "Ime",
    "Organization" : "Ustanova",
    "Title" : "Naslov",
    "Add field ..." : "Dodaj polje ...",
    "+ New contact" : "+ Nov stik",
    "No search result for {query}" : "Ni zadetkov iskanja za {query}",
    "_%n contact_::_%n contacts_" : ["%n stik","%n stika","%n stiki","%n stikov"],
    "Post office box" : "Poštni predal",
    "Postal code" : "Poštna številka",
    "City" : "Mesto",
    "State or province" : "Zvezna država ali provinca",
    "Country" : "Država",
    "Address" : "Naslov",
    "(new group)" : "(nova skupina)",
    "Last name" : "Priimek",
    "First name" : "Ime",
    "Additional names" : "Druga imena",
    "Prefix" : "Predpona",
    "Suffix" : "Pripona",
    "All contacts" : "Vsi stiki",
    "Not grouped" : "Brez skupine",
    "New contact" : "Nov stik",
    "{addressbook} shared by {owner}" : "Souporabo imenika {addressbook} je omogočil uporabnik {owner}",
    "No contacts in file. Only VCard files are allowed." : "V datoteki ni vpisanih stikov. Dovoljeni so le vpisi datotek VCard.",
    "Nickname" : "Vzdevek",
    "Detailed name" : "Podrobno ime",
    "Notes" : "Sporočilca",
    "Website" : "Spletna stran",
    "Federated Cloud ID" : "ID zveznega oblaka",
    "Home" : "Domači naslov",
    "Work" : "Službeni naslov",
    "Other" : "Drugo",
    "Groups" : "Skupine",
    "Birthday" : "Rojstni dan",
    "Anniversary" : "Obletnica",
    "Date of death" : "Datum smrti",
    "Email" : "Elektronski naslov",
    "Instant messaging" : "Hipno sporočanje",
    "Phone" : "Telefon",
    "Mobile" : "Mobilni telefon",
    "Fax" : "Faks",
    "Fax home" : "Domači faks",
    "Fax work" : "Službeni faks",
    "Pager" : "Pozivnik",
    "Voice" : "Glas",
    "Social network" : "Družbeno omrežje",
    "Settings" : "Nastavitve"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
